import { useCallback, useEffect, useRef, useState } from 'react';

function useAutoFocus(navigation) {
  const refs = useRef([]);
  const [currentFocus, setCurrentFocus] = useState(0);
  const mounted = useRef(false);
  const getRef = useCallback(index => {
    return el => {
      refs.current[index] = el;

      if (!mounted.current && el && index === 0) {
        if (navigation) {
          return navigation.addListener('transitionEnd', () => {
            el.focus();
            mounted.current = true;
          });
        } else {
          el.focus();
          mounted.current = true;
        }
      }
    };
  }, [navigation]);

  const nextFocus = () => {
    setCurrentFocus(prev => prev + 1);
  };

  const blur = useCallback(() => {
    const currentElement = refs.current[currentFocus];

    if (currentElement) {
      currentElement.blur();
    }
  }, [currentFocus, refs]);
  const focus = useCallback(function () {
    let force = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
    const currentElement = refs.current[currentFocus];

    if (currentElement || force) {
      currentElement.focus();
    }
  }, [currentFocus, refs]);
  useEffect(() => {
    const nextElement = refs.current[currentFocus];

    if (nextElement && mounted.current) {
      nextElement.focus();
    }
  }, [currentFocus]);
  const autoFocusProps = useCallback(index => ({
    onPressIn: () => setCurrentFocus(index),
    ref: getRef(index),
    inputRef: getRef(index),
    onSubmitEditing: nextFocus
  }), [getRef]);
  return {
    refs,
    getRef,
    nextFocus,
    currentFocus,
    blur,
    setCurrentFocus,
    focus,
    autoFocusProps
  };
}

export default useAutoFocus;
//# sourceMappingURL=useAutoFocus.js.map